@@ -276,10 +276,21 @@ def detailfamily_list(request,hashed):
     form = CustumDetailFamily_form(userAddress.employee.village.id)
     # Prosesu aumenta membru familia   bazeia  ba dados anterior. wainhira iha request post husi formulario input ne'ebe localiza iha pajina lista membru familia
     if request.POST :
-        _, newidf = getlastid(DetailFamily)
+
+
+
+        idf = getlastid_kinosrp(DetailFamily,str(userAddress.employee.village.id))
+        hashidf = hash_md5(str(idf))
+
+
+        # _, newidf = getlastid(DetailFamily)
         
-        idf = str(userAddress.employee.village.id)+str(newidf) 
-        hashidf = hash_md5(str(newidf))
+        # idf = str(userAddress.employee.village.id)+str(newidf) 
+        # hashidf = hash_md5(str(newidf))
+
+
+
+ 
         dataagora = timezone.now()
         form = CustumDetailFamily_form(userAddress.employee.village.id,request.POST)
         if form.is_valid():
